@@ -7,6 +7,7 @@ git repos in them, then does a git status on them """
 import os
 from pathlib import Path
 import sys
+
 from git import Repo  # type: ignore
 
 __version__ = "0.0.11"
@@ -28,7 +29,12 @@ def handle_diff(
     message: str="Changes",
     ) -> None:
     """ does the checking of the diffs, outputs information on what's changed """
-    if repo_object.head.commit.diff(compare):
+    try:
+        diff = repo_object.head.commit.diff(compare)
+    except ValueError as error_message:
+        logger.error("Failed to get a diff in repo {} : {}", repo_object, error_message)
+        return
+    if diff:
         logger.info(f"{message}:")
         for diff_added in repo_object.head.commit.diff(compare):
             if diff_added.renamed:
